@@ -1,8 +1,7 @@
 package Evo::XS;
 use Evo;
 use XSLoader;
-XSLoader::load("Evo::XS");
-
+XSLoader::load("Evo::XS", '0.004');
 
 1;
 
@@ -20,7 +19,7 @@ Evo::XS - Evo::XS - Evo parts written in C for performance
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 AUTHOR
 
